---
title: "Cegid Pulse OS: Revolutionizing Business Management with AG2"
authors:
  - leandro_duarte
tags: [AG2, Automation]
---

> I appreciate how AG2 prioritizes multi-agentic workflows from the get-go. It has been helping us solve complex problems by leveraging conversational collaboration between specialized agents. More importantly, it’s remarkably easy and fast to use, significantly speeding up the development of our agentic-AI system for many use cases.
>
> > Fernando Cruz, Data Scientist at Cegid

![banner](img/banner.png)

## Overview

Cegid is a global technology company specializing in enterprise software solutions. It primarily focuses on providing cloud-based management solutions for various industries, including retail, finance, and human resources. The company offers tools for ERP, talent management, and point-of-sale systems, helping businesses streamline operations, improve decision-making, and enhance customer experiences.

## Challenge

The world is evolving at an unprecedented pace, opening doors to limitless opportunities. Our customers are eagerly awaiting innovation in the way we deliver our products and see immense potential for growth. To meet this evolving context, we need to rethink the way we deliver value to Cegid's markets.

We need a new factory, a new platform and a new operating system that will reshape Cegid's customer journey. We need to guarantee customers results based on non-deterministic execution. We need to do conversational programming with users to let them build their own environment. The pace of traditional development won't be enough for the vibe coding that is already catching up with us. The successful transition will significantly impact our company's EBITDA.

The Cegid Pulse aims to **revolutionize business process management** with Generative AI. The Pulse OS is a framework that enables the development of this vision.

Pulse OS is a cutting-edge platform designed to seamlessly integrate generative AI into your Cegid applications. It orchestrates multiple Business AI Agents to efficiently manage all your business processes. With Pulse OS, you can streamline tasks such as processing expenses, paying invoices, chasing customer debts, collecting employee payroll details, analyzing financial KPIs, generating reports in various formats, and much more. Additionally, Cegid Pulse optimizes your company's processes to enhance service delivery to your clients.

Key challenges faced while building Cegid Pulse:

- **Interoperability**: Ensure that agents work seamlessly with existing systems.
- **Previsibility**: Make sure that we increase the number of correct answers
- **Scalability**: Managing the resources needed as the number of agents grows, while maintaining the performance and responsiveness.
- **Security and Privacy**: Protecting agent interactions from malicious activities and ensuring data privacy


## Solution

Incorporating AG2 into this framework enables us to leverage cutting edge out of the box agentic capabilities, with an active community and roadmap aligned with our vision, increasing the speed of development.

Discover the powerful framework capabilities in this video:

<div class="user-story-youtube-container">
  <iframe
    class="w-full aspect-video rounded-md"
    src="https://www.youtube.com/embed/Q7hV-KKOcoY?si=BUaIAw8yFzM76QHt"
    title="YouTube video player"
    frameborder="0"
    allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
    allowfullscreen
  ></iframe>
</div>


Within AG2 we are using the conversational agent, the human in the loop, orchestrating multiple agents, skills, tools and code generation.

We've started this journey with AutoGen, so after the fork for AG2 it was quite obvious the choice for AG2 in terms of initial vision, goals and being on top of an open-source platform.
It was quite easy to integrate in our solutions, regarding that we use APIs for most of our communications with OAuth protocol.

This is a basic diagram to show the execution of a request, from user intent to the final response:

![banner](img/01.png)


## Results/Impact

Now we are launching the first version of PulseOS in production at scale, inside Cegid Business, to feel the first user interactions with the system, inspect and adapt. That will be an impactful moment in Cegid, to increase the value of the product. It will unlock seamless interaction with our systems through natural language! Enhance your engagement and simplify your experience like never before.

## What's Next

The next step will be, alongside AG2, catalyze the adoption of PulseOS framework for our products, enabling end users to have personalized experiences, automate repetitive tasks, have better decision support, greater control and adaptability.
